@@ -62,400 +62,6 @@ static struct
   radio_text_bits, NULL}
 };
  
- 
-/* Widget Type Lookups/Macros
-   
-   Based on/modified from functions in
-   Smooth-Engine.
-*/ 
-gboolean
-redmond_object_is_a (GtkWidget * widget, gchar * type_name)
-{
-  gboolean result = FALSE;
- 
-  if ((widget))
-    {
-      GType tmp = g_type_from_name (type_name);
-      if (tmp)
-	result = g_type_check_instance_is_a ((GTypeInstance *) widget, tmp);
-    }
- 
-  return result;
-}
- 
-gboolean
-redmond_is_combo_box_entry (GtkWidget * widget)
-{
-  gboolean result = FALSE;
- 
-  if ((widget) && (widget->parent))
-    {
-      if (IS_COMBO_BOX_ENTRY (widget->parent))
-	result = TRUE;
-      else
-	result = redmond_is_combo_box_entry (widget->parent);
-    }
-  return result;
-}
- 
-static gboolean
-combo_box_is_using_list (GtkWidget * widget)
-{
-  gboolean result = FALSE;
- 
-  if ((widget) && (IS_COMBO_BOX (widget->parent)))
-    {
-      gboolean *tmp = NULL;
- 
-      gtk_widget_style_get (widget, "appears-as-list", &result, NULL);
- 
-      if (tmp)
-	result = *tmp;
-    }
- 
-  return result;
-}
- 
-gboolean
-redmond_is_combo_box (GtkWidget * widget, gboolean as_list)
-{
-  gboolean result = FALSE;
- 
-  if ((widget) && (widget->parent))
-    {
-      if (IS_COMBO_BOX (widget->parent))
-        {
-          if (as_list)
-            result = (combo_box_is_using_list(widget));
-          else
-            result = (!combo_box_is_using_list(widget));
-        }
-      else
-	result = redmond_is_combo_box (widget->parent, as_list);
-    }
-  return result;
-}
- 
-gboolean
-redmond_is_combo (GtkWidget * widget)
-{
-  gboolean result = FALSE;
- 
-  if ((widget) && (widget->parent))
-    {
-      if (IS_COMBO (widget->parent))
-	result = TRUE;
-      else
-	result = redmond_is_combo (widget->parent);
-    }
-  return result;
-}
- 
-gboolean
-redmond_is_in_combo_box (GtkWidget * widget)
-{
-  return ((redmond_is_combo (widget) || redmond_is_combo_box (widget, TRUE) || redmond_is_combo_box_entry (widget)));
-}
- 
-gboolean
-redmond_is_toolbar_item (GtkWidget * widget)
-{
-  gboolean result = FALSE;
- 
-  if ((widget) && (widget->parent)) {
-    if ((IS_BONOBO_TOOLBAR (widget->parent))
-	|| (IS_BONOBO_DOCK_ITEM (widget->parent))
-	|| (IS_EGG_TOOLBAR (widget->parent))
-	|| (IS_TOOLBAR (widget->parent))
-	|| (IS_HANDLE_BOX (widget->parent)))
-      result = TRUE;
-    else
-      result = redmond_is_toolbar_item (widget->parent);
-  }
-  return result;
-}
- 
-gboolean
-redmond_is_panel_widget_item (GtkWidget * widget)
-{
-  gboolean result = FALSE;
- 
-  if ((widget) && (widget->parent))
-    {
-      if (IS_PANEL_WIDGET (widget->parent))
-	result = TRUE;
-      else
-	result = redmond_is_panel_widget_item (widget->parent);
-    }
-  return result;
-}
- 
-gboolean 
-redmond_is_bonobo_dock_item (GtkWidget * widget)
-{
-  gboolean result = FALSE;
- 
-  if ((widget))
-    {
-      if (IS_BONOBO_DOCK_ITEM(widget) || IS_BONOBO_DOCK_ITEM (widget->parent))
-	result = TRUE;
-      else if (IS_BOX(widget) || IS_BOX(widget->parent))
-        {
-          GtkContainer *box = IS_BOX(widget)?GTK_CONTAINER(widget):GTK_CONTAINER(widget->parent);
-          GList *children = NULL, *child = NULL;
- 
-          children = gtk_container_get_children(box);
-              
-          for (child = g_list_first(children); child; child = g_list_next(child))
-            {
-	      if (IS_BONOBO_DOCK_ITEM_GRIP(child->data))
-	        {
-	          result = TRUE;
-	          child = NULL;
-	        }
-            }	            
-         
-          if (children)   
-  	    g_list_free(children);
-	}
-    }
-  return result;
-}
- 
-/***********************************************/
-/* Widget Sizing                               */
-/***********************************************/
- 
-/***********************************************
- * redmond_sanitize_parameters -
- *  
- *   Ensure Size and Values are valid
- *
- *   Taken from Smooth based on Metal
- ***********************************************/
-gboolean
-redmond_sanitize_parameters(GtkStyle * style,
-  	            GdkWindow * window,
-	            gint * width,
-	            gint * height)
-{
-  if (!style) return FALSE;
-  if (!window) return FALSE;
- 
-  if ((width) && (height)) {
-    if ((*width == -1) && (*height == -1))
-      gdk_drawable_get_size (window, width, height);
-    else if (*width == -1)
-      gdk_drawable_get_size(window, width, NULL);
-    else if (*height == -1)
-      gdk_drawable_get_size (window, NULL, height);  
-  }
-  return TRUE;  
-}
- 
-/***********************************************
- * redmond_option_menu_get_props -
- *  
- *   Find Option Menu Size and Spacing
- *
- *   Taken from Smooth
- ***********************************************/ 
-static GtkRequisition default_option_indicator_size = { 9, 5 }; 
-static GtkBorder default_option_indicator_spacing = { 7, 5, 2, 2 }; 
- 
-void
-redmond_option_menu_get_props (GtkWidget * widget,
-		       GtkRequisition * indicator_size,
-		       GtkBorder * indicator_spacing)
-{
-  GtkRequisition *tmp_size = NULL;
-  GtkBorder *tmp_spacing = NULL;
- 
-  if ((widget) && IS_OPTION_MENU(widget))
-    gtk_widget_style_get (widget,
-			  "indicator_size", &tmp_size,
-			  "indicator_spacing", &tmp_spacing, NULL);
- 
-  if (tmp_size)
-    {
-      *indicator_size = *tmp_size;
-      g_free (tmp_size);
-    }
-  else
-    *indicator_size = default_option_indicator_size;
- 
-  if (tmp_spacing)
-    {
-      *indicator_spacing = *tmp_spacing;
-      g_free (tmp_spacing);
-    }
-  else
-    *indicator_spacing = default_option_indicator_spacing;
-}
- 
-/***********************************************/
-/* Colour Shade Routines                       */
-/***********************************************/
- 
-/***********************************************
- * color_get_rgb_from_hsb -
- *  
- *   Get HSB values from RGB values.
- *
- *   Taken from Smooth but originated in GTK+
- ***********************************************/
-static void
-color_get_hsb_from_rgb (gdouble red, 
-                        gdouble green, 
-                        gdouble blue,	
-                        gdouble *hue, 
-                        gdouble *saturation,
-                        gdouble *brightness) 
-{
-  gdouble min, max, delta;
-    
-  if (red > green)
-    {
-      max = MAX(red, blue);
-      min = MIN(green, blue);      
-    }
-  else
-    {
-      max = MAX(green, blue);
-      min = MIN(red, blue);      
-    }
-  
-  *brightness = (max + min) / 2;
- 	
-  if (max == min)
-    {
-      *hue = 0;
-      *saturation = 0;
-    }	
-  else
-    {
-      if (*brightness <= 0.5)
-        *saturation = (max - min) / (max + min);
-      else
-        *saturation = (max - min) / (2 - max - min);
-       
-      delta = max -min;
- 
-      if (red == max)
-        *hue = (green - blue) / delta;
-      else if (green == max)
-        *hue = 2 + (blue - red) / delta;
-      else if (blue == max)
-        *hue = 4 + (red - green) / delta;
- 
-      *hue *= 60;
-      if (*hue < 0.0)
-        *hue += 360;
-    }
-}
- 
-/***********************************************
- * color_get_rgb_from_hsb -
- *  
- *   Get RGB values from HSB values.
- *
- *   Taken from Smooth but originated in GTK+
- ***********************************************/
-#define MODULA(number, divisor) (((gint)number % divisor) + (number - (gint)number))
-static void
-color_get_rgb_from_hsb (gdouble hue, 
-                        gdouble saturation,
-                        gdouble brightness, 
-                        gdouble *red, 
-                        gdouble *green, 
-                        gdouble *blue)
-{
-  gint i;
-  gdouble hue_shift[3], color_shift[3];
-  gdouble m1, m2, m3;
-	  
-  if (brightness <= 0.5)
-    m2 = brightness * (1 + saturation);
-  else
-    m2 = brightness + saturation - brightness * saturation;
- 
-  m1 = 2 * brightness - m2;
- 
-  hue_shift[0] = hue + 120;
-  hue_shift[1] = hue;
-  hue_shift[2] = hue - 120;
- 
-  color_shift[0] = color_shift[1] = color_shift[2] = brightness;	
- 
-  i = (saturation == 0)?3:0;
- 
-  for (; i < 3; i++)
-    {
-      m3 = hue_shift[i];
- 
-      if (m3 > 360)
-        m3 = MODULA(m3, 360);
-      else if (m3 < 0)
-        m3 = 360 - MODULA(ABS(m3), 360);
- 
-      if (m3 < 60)
-        color_shift[i] = m1 + (m2 - m1) * m3 / 60;
-      else if (m3 < 180)
-        color_shift[i] = m2;
-      else if (m3 < 240)
-        color_shift[i] = m1 + (m2 - m1) * (240 - m3) / 60;
-      else
-        color_shift[i] = m1;
-    }	
- 
-  *red = color_shift[0];
-  *green = color_shift[1];
-  *blue = color_shift[2];	
-}
- 
-/***********************************************
- * redmond_composite_color_shade -
- *  
- *   Calculate a composite color shade ratio.
- *
- *   Taken from Smooth but originated in GTK+
- ***********************************************/
-void
-redmond_composite_color_shade(GdkColor *original, 
-                      gdouble shade_ratio,
-                      GdkColor *composite)
-{
-  gdouble red=0;
-  gdouble green=0;
-  gdouble blue=0;
- 
-  gdouble hue = 0;
-  gdouble saturation = 0;
-  gdouble brightness = 0;
- 
-  red = (gdouble) original->red / 65535.0;
-  green = (gdouble) original->green / 65535.0;
-  blue = (gdouble) original->blue / 65535.0;
- 
-  color_get_hsb_from_rgb (red, green, blue, &hue, &saturation, &brightness);
- 
-  brightness = MIN(brightness*shade_ratio, 1.0);
-  brightness = MAX(brightness, 0.0);
-  
-  saturation = MIN(saturation*shade_ratio, 1.0);
-  saturation = MAX(saturation, 0.0);
-  
-  color_get_rgb_from_hsb (hue, saturation, brightness, &red, &green, &blue);
- 
-  composite->red = red * 65535.0;
-  composite->green = green * 65535.0;
-  composite->blue = blue * 65535.0;
-}
- 
-/***********************************************/
-/* Base Drawing Routines                       */
-/***********************************************/
- 
 /***********************************************
  * redmond_draw_part -
  *  
@@ -571,47 +177,7 @@ do_redmond_draw_cross_hatch_fill (GtkStyle * style,
   g_object_unref (gc);
   g_object_unref (pixmap);
 }
- 
-/***********************************************
- * do_redmond_draw_shadow -
- *  
- *   A simple routine to draw thin border
- *   with a topleft and bottomright gc.
- *   Used to cut down the length of all the 
- *   functions.
- *    
- *   It originated in Smooth-Engine.
- ***********************************************/
-void
-do_redmond_draw_shadow (GdkWindow * window,
-		GdkGC * tl_gc,
-		GdkGC * br_gc,
-		gint x,
-		gint y, 
-		gint width, 
-		gint height, 
-		gboolean topleft_overlap)
-{
-  if (topleft_overlap)
-    {
-      gdk_draw_line (window, br_gc, x, y + height - 1, x + width - 1,
-		     y + height - 1);
-      gdk_draw_line (window, br_gc, x + width - 1, y, x + width - 1,
-		     y + height - 1);
-    }
- 
-  gdk_draw_line (window, tl_gc, x, y, x, y + height - 1);
-  gdk_draw_line (window, tl_gc, x, y, x + width - 1, y);
- 
-  if (!topleft_overlap)
-    {
-      gdk_draw_line (window, br_gc, x, y + height - 1, x + width - 1,
-		     y + height - 1);
-      gdk_draw_line (window, br_gc, x + width - 1, y, x + width - 1,
-		     y + height - 1);
-    }
-}
- 
+  
 /***********************************************
  * do_redmond_draw_check -
  *  
@@ -621,26 +187,75 @@ do_redmond_draw_shadow (GdkWindow * window,
  *   It originated in Smooth-Engine.
  ***********************************************/
 void
-do_redmond_draw_check (GdkWindow * window,
-	       GdkGC * gc,
-               gint x, 
-               gint y, 
-               gint width, 
-               gint height)
-{
-  x += 1;
-  y += 1;
-  width -= 2;
-  height -= 2;
- 
-  /* short diagonal */
-  gdk_draw_line (window, gc, x + 0, y + height - 5, x + 0, y + height - 3);	/* Left Line */
-  gdk_draw_line (window, gc, x + 1, y + height - 4, x + 1, y + height - 2);	/* Right Line */
- 
-  /* Long Diagonal */
-  gdk_draw_line (window, gc, x + 2, y + height - 3, x + width - 1, y + 0);	/* Top Line */
-  gdk_draw_line (window, gc, x + 2, y + height - 2, x + width - 1, y + 1);	/* Center Line */
-  gdk_draw_line (window, gc, x + 2, y + height - 1, x + width - 1, y + 2);	/* Bottom Line */
+do_redmond_draw_check (cairo_t *cr,
+                       CairoColor * color,
+                       gint x, 
+                       gint y, 
+                       gint width, 
+                       gint height)
+{ 
+  double left, top;
+  int scale;
+
+  scale = MIN(width, height);
+
+  if (!(scale % 2))
+    scale -= 1;
+
+  if (scale <= 11)
+    scale = 9;
+
+  left = x + floor((width - scale) / 2) + 0.5;
+  top = y + floor((height - scale) / 2) + 0.5;
+
+  cairo_save(cr);
+
+  ge_cairo_set_color(cr, color);	
+  cairo_set_line_width(cr, 0.5);
+/*
+    0   1   2   3   4   5   6   7   8
+  +---+---+---+---+---+---+---+---+---+
+0 |   |   |   |   |   |   |   |   |   |
+  +---+---+---+---+---+---+---+---+---+
+1 |   |   |   |   |   |   |   | x |   |
+  +---+---+---+---+---+---+---+---+---+
+2 |   |   |   |   |   |   | x | x |   |
+  +---+---+---+---+---+---+---+---+---+
+3 |   | x |   |   |   | x | x | x |   |
+  +---+---+---+---+---+---+---+---+---+
+4 |   | x | x |   | x | x | x |   |   |
+  +---+---+---+---+---+---+---+---+---+
+5 |   | x | x | x | x | x |   |   |   |
+  +---+---+---+---+---+---+---+---+---+
+6 |   |   | x | x | x |   |   |   |   |
+  +---+---+---+---+---+---+---+---+---+
+7 |   |   |   | x |   |   |   |   |   |
+  +---+---+---+---+---+---+---+---+---+
+8 |   |   |   |   |   |   |   |   |   |
+  +---+---+---+---+---+---+---+---+---+
+
+*/
+
+  cairo_move_to(cr, left + floor((1*scale)/9), top + floor((3*scale)/9)); //(1,3)
+  cairo_line_to(cr, left + floor((1*scale)/9), top + floor((5*scale)/9)); //(1,5)
+  cairo_line_to(cr, left + floor((3*scale)/9), top + floor((7*scale)/9)); //(3,7)
+  cairo_line_to(cr, left + floor((7*scale)/9), top + floor((3*scale)/9)); //(7,3)
+  cairo_line_to(cr, left + floor((7*scale)/9), top + floor((1*scale)/9)); //(7,1)
+  cairo_line_to(cr, left + floor((3*scale)/9), top + floor((5*scale)/9)); //(3,5)
+  cairo_line_to(cr, left + floor((1*scale)/9), top + floor((3*scale)/9)); //(1,3)
+
+  cairo_fill(cr);
+
+  cairo_move_to(cr, left + floor((1*scale)/9), top + floor((3*scale)/9)); //(1,3)
+  cairo_line_to(cr, left + floor((1*scale)/9), top + floor((5*scale)/9)); //(1,5)
+  cairo_line_to(cr, left + floor((3*scale)/9), top + floor((7*scale)/9)); //(3,7)
+  cairo_line_to(cr, left + floor((7*scale)/9), top + floor((3*scale)/9)); //(7,3)
+  cairo_line_to(cr, left + floor((7*scale)/9), top + floor((1*scale)/9)); //(7,1)
+  cairo_line_to(cr, left + floor((3*scale)/9), top + floor((5*scale)/9)); //(3,5)
+  cairo_line_to(cr, left + floor((1*scale)/9), top + floor((3*scale)/9)); //(1,3)
+  cairo_stroke(cr);
+
+  cairo_restore(cr);
 }
  
 /***********************************************
@@ -654,8 +269,8 @@ do_redmond_draw_check (GdkWindow * window,
  *   both which  were based on ThinIce's.
  ***********************************************/
 void
-do_redmond_draw_arrow (GdkWindow * window,
-               GdkGC * gc,
+do_redmond_draw_arrow (cairo_t *cr,
+               CairoColor * color,
                GtkArrowType arrow_type,
                gint x, 
                gint y, 
@@ -710,10 +325,27 @@ do_redmond_draw_arrow (GdkWindow * window,
           increment = -1;
         }
  
-      for (i = extra; i < height; i++)
-        gdk_draw_line(window, gc, 
-                      x + (i - extra), start + i * increment, 
-                      x + width - (i - extra) - 1,  start + i * increment);
+      cairo_save(cr);
+
+      ge_cairo_set_color(cr, color);	
+      cairo_set_line_width (cr, 0.5);
+
+      cairo_move_to(cr, x + 0.5, start + 0.5);
+      cairo_line_to(cr, x + width - 0.5, start + 0.5);
+      cairo_line_to(cr, x + ((height - 1) - extra) + 0.5, start + (height - 1)*increment + 0.5);
+      cairo_line_to(cr, x + 0.5, start + 0.5);
+
+      cairo_stroke(cr);
+
+
+      cairo_move_to(cr, x + 0.5, start + 0.5);
+      cairo_line_to(cr, x + width - 0.5, start + 0.5);
+      cairo_line_to(cr, x + ((height - 1) - extra) + 0.5, start + (height - 1)*increment + 0.5);
+      cairo_line_to(cr, x + 0.5, start + 0.5);
+
+      cairo_fill(cr);
+
+      cairo_restore(cr);
     }
   else
     {
@@ -757,10 +389,27 @@ do_redmond_draw_arrow (GdkWindow * window,
           increment = -1;
         }
  
-      for (i = extra; i < width; i++)
-        gdk_draw_line(window, gc, 
-                      start + i * increment, y + (i - extra), 
-                      start + i * increment, y + height - (i - extra) - 1);
+      cairo_save(cr);
+
+      ge_cairo_set_color(cr, color);	
+      cairo_set_line_width (cr, 0.5);
+
+      cairo_move_to(cr, start + 0.5, y + 0.5);
+      cairo_line_to(cr, start + 0.5, y + height - 0.5);
+      cairo_line_to(cr, start + (width - 1)*increment + 0.5, y + ((width - 1) - extra) + 0.5);
+      cairo_line_to(cr, start + 0.5, y + 0.5);
+
+      cairo_stroke(cr);
+
+
+      cairo_move_to(cr, start + 0.5, y + 0.5);
+      cairo_line_to(cr, start + 0.5, y + height - 0.5);
+      cairo_line_to(cr, start + (width - 1)*increment + 0.5, y + ((width - 1) - extra) + 0.5);
+      cairo_line_to(cr, start + 0.5, y + 0.5);
+
+      cairo_fill(cr);
+
+      cairo_restore(cr);
     }
 }
  
@@ -775,36 +424,40 @@ do_redmond_draw_arrow (GdkWindow * window,
  *   spacer line.
  ***********************************************/
 void
-do_redmond_draw_line(GdkWindow * window,
-             GdkGC * dark_gc,
-             GdkGC * light_gc,
+do_redmond_draw_line(cairo_t *cr,
+             CairoColor * dark,
+             CairoColor * light,
              GdkRectangle * area,
              gint start,
              gint end,
              gint base,
              gboolean horizontal)
 {  
-  if (area)
-    {
-      gdk_gc_set_clip_rectangle (dark_gc, area);
-      gdk_gc_set_clip_rectangle (light_gc, area);
-    }
- 
+  cairo_set_line_width (cr, 1);
+
   if (horizontal) 
     {
-      gdk_draw_line (window, dark_gc, start + 1, base + 0, end - 2, base + 0);
-      gdk_draw_line (window, light_gc, start + 1, base + 1, end - 2, base + 1);
+      ge_cairo_set_color(cr, dark);	
+      cairo_move_to(cr, start + 1.5, base + 0.5);
+      cairo_line_to(cr, end - 1.5, base + 0.5);
+      cairo_stroke(cr);
+
+      ge_cairo_set_color(cr, light);	
+      cairo_move_to(cr, start + 1.5, base + 1.5);
+      cairo_line_to(cr, end - 1.5, base + 1.5);
+      cairo_stroke(cr);
     } 
   else 
     {
-      gdk_draw_line (window, dark_gc, base + 0, start + 1, base + 0, end - 2);
-      gdk_draw_line (window, light_gc, base + 1, start + 1, base + 1, end - 2);
-    }
-   
-  if (area)
-    {
-      gdk_gc_set_clip_rectangle (dark_gc, NULL);
-      gdk_gc_set_clip_rectangle (light_gc, NULL);
+      ge_cairo_set_color(cr, dark);	
+      cairo_move_to(cr, base + 0.5, start + 1.5);
+      cairo_line_to(cr, base + 0.5, end - 1.5);
+      cairo_stroke(cr);
+
+      ge_cairo_set_color(cr, light);	
+      cairo_move_to(cr, base + 1.5, start + 1.5);
+      cairo_line_to(cr, base + 1.5, end - 1.5);
+      cairo_stroke(cr);
     }
 }
  
