@@ -1,9 +1,10 @@
 #include <gtk/gtkstyle.h>
+#include "ge-support.h"
 
 typedef struct _ThiniceStyle ThiniceStyle;
 typedef struct _ThiniceStyleClass ThiniceStyleClass;
 
-extern GType thinice_type_style G_GNUC_INTERNAL;
+extern GType thinice_type_style;
 
 #define THINICE_TYPE_STYLE              thinice_type_style
 #define THINICE_STYLE(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), THINICE_TYPE_STYLE, ThiniceStyle))
@@ -15,6 +16,7 @@ extern GType thinice_type_style G_GNUC_INTERNAL;
 struct _ThiniceStyle
 {
   GtkStyle parent_instance;
+  CairoColorCube color_cube;
 };
 
 struct _ThiniceStyleClass
@@ -22,6 +24,6 @@ struct _ThiniceStyleClass
   GtkStyleClass parent_class;
 };
 
-void thinice_style_register_type (GTypeModule *module) G_GNUC_INTERNAL;
+void thinice_style_register_type (GTypeModule *module);
 
 
